@@ -35,11 +35,19 @@ class Importer(object):
     def moderators_get(self):
         return [u for u in self.mailman.user.values() if u.get('moderator')]
 
+    @staticmethod
+    def category2moderators_group(name):
+        return f'{name}-mo'
+
     def group_moderators_name(self):
-        return Discourse.category2moderators_group(self.name_get())
+        return Discourse.enforce_group_name_length(self.category2moderators_group(self.name_get()))
+
+    @staticmethod
+    def category2members_group(name):
+        return f'{name}-me'
 
     def group_members_name(self):
-        return Discourse.category2members_group(self.name_get())
+        return Discourse.enforce_group_name_length(self.category2members_group(self.name_get()))
 
     def users_add(self):
         before = {}
@@ -173,6 +181,7 @@ class Importer(object):
             Mailman.ROSTER_ADMINS: Discourse.GROUP_MEMBERS_VISIBILITY_LEVEL_GROUP_OWNERS_AND_STAFF,
         }[self.mailman.info['private_roster']]
         return {
+            'group[full_name]': self.category2moderators_group(self.name_get()),
             'group[visibility_level]': '0',
             'group[members_visibility_level]': members_visibility_level,
             'group[public_admission]': 'false',
@@ -235,7 +244,9 @@ class Importer(object):
                 'group[members_visibility_level]': m_group_owners_and_staff,
             },
         }
-        return converter[(private_roster, policy)]
+        kwargs = converter[(private_roster, policy)]
+        kwargs['group[full_name]'] = self.category2members_group(self.name_get())
+        return kwargs
 
     def settings(self):
         kwargs = {
@@ -272,7 +283,7 @@ class Importer(object):
         logger.info('Adding users')
         (before['members'], after['members']) = self.users_add()
         logger.info('Populating the moderators group')
-        (before['group-moderators'], after['group-moderators']) = (
+        (before['group-moderators'], _) = (
             self.discourse.group_create(self.group_moderators_name()))
         (before['group-moderators-list'], after['group-moderators-list']) = self.group_members_add(
             self.group_moderators_name(), self.moderators_get(), self.owners_get())
