@@ -81,7 +81,7 @@ def test_category_create(test_options, name):
 def test_category_set_action(test_options):
     d = DiscourseTest(test_options).connect()
     name = 'CATEGORYNAME'
-    group = d.category2members_group(name)
+    group = 'CATEGORYNAME-me'
     try:
         _, category = d.category_create(name)
         assert category['name'] == name
